#ifndef __TYPES_H__
#define __TYPES_H__

#include "common/common_pch.h"

typedef int64_t MediaTime;
typedef uint8_t binary;

#endif // __TYPES_H__
